@@ -90,7 +90,7 @@ class SnetSDK:
 
 
     def get_service_metadata(self, org_id, service_id):
-        (found, registration_id, metadata_uri, tags) = self.registry_contract.functions.getServiceRegistrationById(bytes(org_id, "utf-8"), bytes(service_id, "utf-8")).call()
+        (found, registration_id, metadata_uri) = self.registry_contract.functions.getServiceRegistrationById(bytes(org_id, "utf-8"), bytes(service_id, "utf-8")).call()
 
         if found is not True:
             raise Exception('No service "{}" found in organization "{}"'.format(service_id, org_id))
